==> jc-1.4.0.tar.gz: javax/swing/UIDefaults__24ProxyLazyValue__244.h <==
// final class javax.swing.UIDefaults$ProxyLazyValue$4

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f959318bed0eec89 javax_swing_UIDefaults__24ProxyLazyValue__244

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIDefaults__24ProxyLazyValue__244_H_
#define _JC_javax_swing_UIDefaults__24ProxyLazyValue__244_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_UIDefaults$object;
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object;

// Typedefs
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object;

typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vmethods	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vmethods;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtable	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtable;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype;

// Constructors
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$method$_init$cba9cc9e114d9448(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$method$createValue$5246839c46d82ae8(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object *, struct _jc_javax_swing_UIDefaults$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$method_info$createValue$5246839c46d82ae8;

// Virtual methods structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vmethods {
	struct _jc_java_lang_Object$object	*(*createValue$5246839c46d82ae8)(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object *, struct _jc_javax_swing_UIDefaults$object *);
};

// Vtable
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vmethods	javax_swing_UIDefaults__24ProxyLazyValue__244;
};

// Vtype
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype {
	_jc_type			type;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_refs {
	struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object	*this;
	_jc_object_array	*val__24objs;
	struct _jc_java_lang_String$object	*val__24methodName;
	_jc_object_array	*val__24clss;
	struct _jc_java_lang_String$object	*val__24className;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$refs {
    _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_refs	javax_swing_UIDefaults__24ProxyLazyValue__244;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_nonrefs	javax_swing_UIDefaults__24ProxyLazyValue__244;
};

// Object instance structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object {
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype	*vtype;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIDefaults__24ProxyLazyValue__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$class_object;

#endif	/* _JC_javax_swing_UIDefaults__24ProxyLazyValue__244_H_ */

==> jc-1.4.5.tar.gz: javax/swing/UIDefaults__24ProxyLazyValue__244.h <==
// final class javax.swing.UIDefaults$ProxyLazyValue$4

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 55d149a3380334a6 javax_swing_UIDefaults__24ProxyLazyValue__244

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIDefaults__24ProxyLazyValue__244_H_
#define _JC_javax_swing_UIDefaults__24ProxyLazyValue__244_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_UIDefaults$object;
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object;

// Typedefs
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object;

typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vmethods	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vmethods;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtable	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtable;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype;

// Constructors
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$method$_init$cba9cc9e114d9448(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$method$createValue$5246839c46d82ae8(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$method_info$createValue$5246839c46d82ae8;

// Virtual methods structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vmethods {
	struct _jc_java_lang_Object$object	*(*createValue$5246839c46d82ae8)(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vmethods	javax_swing_UIDefaults__24ProxyLazyValue__244;
};

// Vtype
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype {
	_jc_type			type;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_refs {
	struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object	*this;
	_jc_object_array	*val__24objs;
	struct _jc_java_lang_String$object	*val__24methodName;
	_jc_object_array	*val__24clss;
	struct _jc_java_lang_String$object	*val__24className;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$refs {
    _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_refs	javax_swing_UIDefaults__24ProxyLazyValue__244;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$sub_nonrefs	javax_swing_UIDefaults__24ProxyLazyValue__244;
};

// Object instance structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$object {
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype	*vtype;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$vtype _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIDefaults__24ProxyLazyValue__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIDefaults__24ProxyLazyValue__244$class_object;

#endif	/* _JC_javax_swing_UIDefaults__24ProxyLazyValue__244_H_ */
